# LCD display interface with scroll support

from doorbell.config import MOCK_LCD

if MOCK_LCD:
    from mocks.mock_lcd import setText
else:
    from grove_rgb_lcd import setText


import threading
import time
from doorbell.utils import log_event

def set_display(message):
    """
    Display a message on the LCD.
    Scrolls automatically if message is too long.
    """
    try:
        if len(message) <= 32:
            line1 = message[:16]
            line2 = message[16:32]
            setText(f"{line1}\n{line2}")
        else:
            # Run scroll in a separate thread to avoid blocking main loop
            t = threading.Thread(target=scroll_text, args=(message,))
            t.daemon = True
            t.start()
    except Exception as e:
        log_event("ERROR", f"LCD error: {e}")

def scroll_text(message, delay=0.3, idle="Smart Doorbell Ready"):
    """
    Scroll text horizontally across the LCD.
    Returns to idle message afterward.
    """
    message = message.strip() + "    "
    try:
        for i in range(len(message) - 15):
            setText(message[i:i+16] + "\n")
            time.sleep(delay)
        set_display(idle)
    except Exception as e:
        log_event("ERROR", f"Scroll failed: {e}")
