# Handles hardware sensor reads (mocked or real)

from doorbell.config import PORTS, MOCK_MODE
import time

# Import the appropriate hardware interface
from doorbell.config import MOCK_MODE

if MOCK_MODE:
    from mocks.mock_gpio import pinMode, digitalRead, analogRead, digitalWrite
else:
    from grovepi import pinMode, digitalRead, analogRead, digitalWrite


def initialise_sensors():
    """Set GPIO modes for sensors and buzzer."""
    pinMode(PORTS["pir"], "INPUT")
    pinMode(PORTS["button"], "INPUT")
    pinMode(PORTS["buzzer"], "OUTPUT")

def read_light():
    """Read value from light sensor (0–1023)."""
    return analogRead(PORTS["light"])

def read_motion():
    """Read motion sensor state (1 = motion, 0 = no motion)."""
    return digitalRead(PORTS["pir"])

def read_button():
    """Read button state (0 = pressed, 1 = not pressed)."""
    return digitalRead(PORTS["button"])

def ring_buzzer(duration=0.2):
    """Activate the buzzer for a set duration (in seconds)."""
    digitalWrite(PORTS["buzzer"], 1)
    time.sleep(duration)
    digitalWrite(PORTS["buzzer"], 0)
