"""
Test suite for the light level sensor.
Covers range validation and night mode threshold logic.
"""

import unittest
from doorbell.sensors import read_light
from doorbell.config import LIGHT_THRESHOLD, PORTS

class TestLightSensor(unittest.TestCase):
    def test_mock_light_read_range(self):
        """
        Ensure that the light sensor returns a valid analog value between 0 and 1023.
        """
        print(f"\n[TEST] Reading light level on pin {PORTS['light']}")
        light = read_light()
        print(f"Light level: {light}")
        self.assertGreaterEqual(light, 0)
        self.assertLessEqual(light, 1023)

    def test_night_mode_threshold(self):
        """
        Verify that the threshold comparison for night mode produces a boolean result.
        """
        print(f"\n[TEST] Comparing light against night mode threshold ({LIGHT_THRESHOLD})")
        light = read_light()
        is_night = light < LIGHT_THRESHOLD
        print(f"Night mode triggered: {is_night}")
        self.assertIsInstance(is_night, bool)
